Usually you will want to use the included lookup that can be accessed via
morphemepiece_lookup(). This function can be used to load a different
lookup from a file.
load_lookup(lookup_file)path to lookup file. File is assumed to be a text file, with one word per line. The lookup value, if different from the word, follows the word on the same line, after a space.
The lookup as a named list. Names are words in lookup.