Learn R Programming

morphemepiece (version 1.2.3)

morphemepiece_cache_dir: Retrieve Directory for Morphemepiece Cache

Description

The morphemepiece cache directory is a platform- and user-specific path where morphemepiece saves caches (such as a downloaded lookup). You can override the default location in a few ways:

  • Option: morphemepiece.dirUse set_morphemepiece_cache_dir to set a specific cache directory for this session

  • Environment: MORPHEMEPIECE_CACHE_DIRSet this environment variable to specify a morphemepiece cache directory for all sessions.

  • Environment: R_USER_CACHE_DIRSet this environment variable to specify a cache directory root for all packages that use the caching system.

Usage

morphemepiece_cache_dir()

Arguments

Value

A character vector with the normalized path to the cache.