Use this function to override the cache path used by morphemepiece for the
current session. Set the MORPHEMEPIECE_CACHE_DIR environment variable
for a more permanent change.
set_morphemepiece_cache_dir(cache_dir = NULL)Character scalar; a path to a cache directory.
A normalized path to a cache directory. The directory is created if the user has write access and the directory does not exist.